Ep18 L'Astrologie - Les mauvaises critiques

Hygiène Mentale

Ep18 L'Astrologie - Les mauvaises critiques

J'ai pendant longtemps critiqué l'Astrologie, mais avec des arguments pas vraiment valides. La stratégie de l'homme de paille, c'est diablement efficace, pour ridiculiser une pratique, mais c'est pas un argument valable. Il faut éviter de faire ça. L'Astrologie c'est du flan, mais pas par ce que c'est physiquement impossible, et pas par ce que les définitions sont arbitraires. L'Astrologie c'est du flan par ce que les résultats expérimentaux sont désastreux. ________________________ ❖ Reportage : L'Oeil du 20h Astrologie entre copier et collé https://www.youtube.com/watch?v=UTSukdz6-fI ❖ Le site de Johan van Santen https://arobasom.com/jai-prouve-que-lhoroscope-du-20mn-etait-bidon/ ❖ Un Article de l'AFIS L’astrologie à l’épreuve : ça ne marche pas, ça n’a jamais marché ! http://www.pseudo-sciences.org/spip.php?article1240 ❖ Serge Bret Morel - L'Astrologie et la Science. Y-a t'il du vrai ?de La conférence : https://www.youtube.com/watch?v=4HaibNZxc-0 Les site : AstroScepticisme : https://astroscept.com ___________________ ❖ L’expérience de S. Carlson (1985) http://muller.lbl.gov/papers/Astrology-Carlson.pdf ❖ A Scientific Inquiry Into the Validity of Astrology, McGrew and McFall, 1990 http://www.skepticalmedia.com/astrology/Scientific%20Inquiry%20into%20Astrology.pdf ❖ Une Meta analyse des experiences sur l'astrologie par G. Dean https://pdfs.semanticscholar.org/2bb2/d5658e1eff0f151a41a25b02b3b5027673b8.pdf ❖ Plein d'autres protocoles experimentaux sur l'Astrologie : http://www.astrology-and-science.com/hpage.htm http://www.astrology-and-science.com/d-meta2.htm _______________ L'Effet Puits : https://cortecs.org/materiel/leffet-puits/ L'Effet Barnum : https://fr.wikipedia.org/wiki/Effet_Barnum ______________ Musique d'intro : Koenjiyakkei Le Facebook : http://facebook.com/HygieneMentale Le Twitter : https://twitter.com/HygieneMentale Le Diaspora* : https://framasphere.org/people/43360ee086750134e9c62a0000053625 Le Mastodon : https://oc.todon.fr/@HygieneMentale Le Site : http://laelith.fr/Zet Le Mail : fauxsceptiques@gmail.com L'Association : http://zetetique.fr Le Tipee : https://www.tipeee.com/hygiene-mentale

17/05/2017